utf8_strncmp

Function utf8_strncmp 

pub unsafe extern "C" fn utf8_strncmp(
    a: *const c_char,
    b: *const c_char,
    n: usize,
) -> c_int
Compares the G_NORMALIZE_ALL_COMPOSE forms of the two strings.

Returns less than, equal to, or greater than zero if the first n characters (not bytes) of a are found, respectively, to be less than, to match, or be greater than the first n characters (not bytes) of b.

  • a: First UTF-8 string to compare, non-null.
  • b: Second UTF-8 string to compare, non-null.
  • n: Maximum number of characters to compare.