query

Function query 

pub unsafe extern "C" fn query(
    name: *const c_char,
    size: c_int,
) -> u32
Query the icon-theme for icon with name and size.

The returned icon will be the best match for the requested size, it should still be resized to the actual size.

name can also be a full path, if prefixed with file://.

Returns the UID identifying the request.