Functions related to Rofi’s menu view.
This corresponds to view.h.
WARNING: This is an undocumented API! See https://github.com/davatorium/rofi/blob/next/include/view.h for the header file itself. As such, the only functions bound here are functions with explicit conformation from the author that they are public.