reload

Function reload 

pub unsafe extern "C" fn reload()
Indicate the current view needs to reload its data. This can only be done when more information is available.

The reloading happens ‘lazy’, multiple calls might be handled at once.

See this comment that confirms this function can be used.